veryscrape package
==================

Subpackages
-----------

.. toctree::

    veryscrape.scrapers

Submodules
----------

veryscrape.cli module
---------------------

.. automodule:: veryscrape.cli
    :members:
    :undoc-members:
    :show-inheritance:

veryscrape.items module
-----------------------

.. automodule:: veryscrape.items
    :members:
    :undoc-members:
    :show-inheritance:

veryscrape.process module
-------------------------

.. automodule:: veryscrape.process
    :members:
    :undoc-members:
    :show-inheritance:

veryscrape.scrape module
------------------------

.. automodule:: veryscrape.scrape
    :members:
    :undoc-members:
    :show-inheritance:

veryscrape.session module
-------------------------

.. automodule:: veryscrape.session
    :members:
    :undoc-members:
    :show-inheritance:

veryscrape.veryscrape module
----------------------------

.. automodule:: veryscrape.veryscrape
    :members:
    :undoc-members:
    :show-inheritance:

veryscrape.wrappers module
--------------------------

.. automodule:: veryscrape.wrappers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: veryscrape
    :members:
    :undoc-members:
    :show-inheritance:
